import { ApplicationCommandOptionData, ApplicationCommandOptionType, CommandInteraction } from "discord.js"
import { CBClient } from "../cbclient"
import { Unit } from "../models/unit"
import { SlashCommand, createArgumentsObject } from "./slash"

interface EquipArguments {
    slot: number
    unit: number
}

export class EquipCommand implements SlashCommand {
	name = 'equip'
    description = 'Equip a unit'
    permission = []
    ownerOnly = false
    guildOnly = false
    //guildID = "739645806100873328" //for testing
    args: ApplicationCommandOptionData[] = [
        {
            name: 'slot',
            type: ApplicationCommandOptionType.Integer,
            description: "The slot to equip to",
            required: true
        },
        {
            name: 'unit',
            type: ApplicationCommandOptionType.Integer,
            description: "The unit ID to equip",
            required: true
        }
    ]

	async execute(int: CommandInteraction) {
        const args = createArgumentsObject<EquipArguments>(int.options.data);
        const client = int.client as CBClient;
        const player = await CBClient.findOrCreatePlayer(int.user.id);

        if (!(await Unit.findOne( { where: { user_id: int.user.id, id: args.unit } } ))) return int.reply({
            content: `That isn't your unit!`
        });

        console.debug(player.slot1 === args.unit);
        if (player.slot1 === args.unit) player.set({slot1:null});
        if (player.slot2 === args.unit) player.set({slot2:null});
        if (player.slot3 === args.unit) player.set({slot3:null});

        switch (args.slot) {
            case 1:
                player.set({slot1:args.unit});
                break;
            case 2:
                player.set({slot2:args.unit});
                break;
            case 3:
                player.set({slot3:args.unit});
                break;
            default:
                await player.save();
                return int.reply({
                    content: `Invalid slot.`
                });
        }

        await player.save();
        return int.reply({
            content: `Equipped to slot ${args.slot}.`
        });
	}
};
